==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredActionProviderEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapRequiredActionProviderEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setId((String) value);
        }
    },
    ALIAS {
        public static final String FIELD_NAME = "Alias";
        public static final String FIELD_NAME_DASHED = "alias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getAlias();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setAlias((String) value);
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (java.util.Map<String,String>) e.getConfig();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setConfig((java.util.Map<String,String>) value);
        }
    },
    DEFAULT_ACTION {
        public static final String FIELD_NAME = "DefaultAction";
        public static final String FIELD_NAME_DASHED = "default-action";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setDefaultAction((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (Boolean) e.isDefaultAction();
        }
    },
    ENABLED {
        public static final String FIELD_NAME = "Enabled";
        public static final String FIELD_NAME_DASHED = "enabled";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (Boolean) e.isEnabled();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setEnabled((Boolean) value);
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setName((String) value);
        }
    },
    PRIORITY {
        public static final String FIELD_NAME = "Priority";
        public static final String FIELD_NAME_DASHED = "priority";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setPriority((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (Integer) e.getPriority();
        }
    },
    PROVIDER_ID {
        public static final String FIELD_NAME = "ProviderId";
        public static final String FIELD_NAME_DASHED = "provider-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getProviderId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setProviderId((String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredActionProviderEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapRequiredActionProviderEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getId();
        }
    },
    ALIAS {
        public static final String FIELD_NAME = "Alias";
        public static final String FIELD_NAME_DASHED = "alias";
        public static final String FIELD_NAME_CAMEL_CASE = "alias";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setAlias((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getAlias();
        }
    },
    CONFIG {
        public static final String FIELD_NAME = "Config";
        public static final String FIELD_NAME_DASHED = "config";
        public static final String FIELD_NAME_CAMEL_CASE = "config";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setConfig((java.util.Map<String,String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (java.util.Map<String,String>) e.getConfig();
        }
    },
    DEFAULT_ACTION {
        public static final String FIELD_NAME = "DefaultAction";
        public static final String FIELD_NAME_DASHED = "default-action";
        public static final String FIELD_NAME_CAMEL_CASE = "defaultAction";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setDefaultAction((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (Boolean) e.isDefaultAction();
        }
    },
    ENABLED {
        public static final String FIELD_NAME = "Enabled";
        public static final String FIELD_NAME_DASHED = "enabled";
        public static final String FIELD_NAME_CAMEL_CASE = "enabled";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (Boolean) e.isEnabled();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setEnabled((Boolean) value);
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        public static final String FIELD_NAME_CAMEL_CASE = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setName((String) value);
        }
    },
    PRIORITY {
        public static final String FIELD_NAME = "Priority";
        public static final String FIELD_NAME_DASHED = "priority";
        public static final String FIELD_NAME_CAMEL_CASE = "priority";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (Integer) e.getPriority();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setPriority((Integer) value);
        }
    },
    PROVIDER_ID {
        public static final String FIELD_NAME = "ProviderId";
        public static final String FIELD_NAME_DASHED = "provider-id";
        public static final String FIELD_NAME_CAMEL_CASE = "providerId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e, T value) {
            e.setProviderId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity e) {
            return (String) e.getProviderId();
        }
    },
}
